﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace HeuristicLab.DataImporter.Command.View {
  public partial class MinMaxCommandView : HeuristicLab.DataImporter.Data.CommandBase.CommandViewBase {
    private MinMaxCommandView() {
      InitializeComponent();
    }

    public MinMaxCommandView(ScalingBetweenMinAndMaxCommand command)
      : this() {
      this.Command = command;
    }

    public new ScalingBetweenMinAndMaxCommand Command {
      get { return (ScalingBetweenMinAndMaxCommand)base.Command; }
      set { base.Command = value; this.UpdateCommand(); }
    }

    public double MinValue {
      get { return Command.MinValue; }
    }

    public double MaxValue {
      get { return Command.MaxValue; }
    }

    private void textBox_Validating(object sender, CancelEventArgs e) {
      TextBox textBox = (TextBox)sender;
      double value;
      if (!double.TryParse(textBox.Text, out value)) {
        e.Cancel = true;
        MessageBox.Show("A numeric value must be entered!");
      } else
        this.UpdateCommand();
    }

    private void UpdateCommand() {
      if (this.Command != null) {
        double value;
        if (double.TryParse(this.txtMin.Text, out value))
          this.Command.MinValue = value;
        if (double.TryParse(this.txtMax.Text, out value))
          this.Command.MaxValue = value;
      }
    }
  }
}
